@@ -1,7 +1,7 @@
 #!/usr/bin/perl -T
 ###
-### analog 4.01           http://www.statslab.cam.ac.uk/~sret1/analog/
-### This program is copyright (c) Stephen R. E. Turner 1995 - 1999 except as
+###              analog 4.1             http://www.analog.cx/
+### This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
 ### stated otherwise. Distribution, usage and modification of this program is
 ### subject to the conditions of the Licence which you should have received
 ### with it. This program comes with no warranty, expressed or implied.
@@ -13,8 +13,8 @@
 
 # 1) uncomment (remove everything before $analog) and edit one of the next two
 #    lines to give the location (full pathname) of the analog executable.
-#       Unix: $analog = '/usr/local/etc/httpd/analog4.01/analog';
-#       Windows: $analog = 'C:\program files\analog 4.01\analog.exe';
+#       Unix: $analog = '/usr/local/etc/httpd/analog-4.1/analog';
+#       Windows: $analog = 'C:\program files\analog 4.1\analog.exe';
 # 2) If you're on Unix, edit the first line in this file to give the location
 #    of Perl (don't remove the #! though).
 # 3) You also need to edit anlgform.html if you want to use the form.
@@ -36,7 +36,7 @@ $ENV{PATH} = '';
 $query = new CGI;
 $|=1;
 $lt = localtime;
-$progname = $0 || 'anlgform.pl';  # can $0 ever not be set?
+$progname = $0 || 'anlgform.pl';
 if (($^O =~ /win32/i || $^O =~ /^win/i) && Win32::GetShortPathName($analog)) {
     $analog = Win32::GetShortPathName($analog);
 } else {
@@ -147,7 +147,7 @@ sub printargs {
 # B) PUT APPROPRIATE DELIMITERS ROUND AN ARGUMENT CONTAINING SPACES
 sub bracket {
     local $_ = $_[0];
-    return $_ unless (/[\s\#]/ || /^'/ || /^"/);
+    return $_ unless (/[\s\#]/ || /^['"\(]/);
     return "\"$_\"" unless (/"/);
     return "'$_'" unless (/'/);
     return "($_)";
@@ -158,7 +158,7 @@ sub bracket {
 sub checkfilechars {
     local ($_);
     foreach (@{$args{$_[0]}}, @{$args{$_[0] . '1'}}) {
-	if (m([^\w\. /\\:-]) || m(\W-|^-|-\W|-$)) {
+	if (m([^\w\. /\\:-]) || m(\W-|^-|-\W|-$)) { # NB \w includes underscore
 	    badreq(403, "Illegal Request", "Unsafe characters in $_[0].");
 	    printf STDERR "[$lt] $progname: Unsafe characters in \"$_[0] $_\" on request from %s\n", $ENV{REMOTE_HOST}?$ENV{REMOTE_HOST}:($ENV{REMOTE_ADDR}?$ENV{REMOTE_ADDR}:"unknown host");
 	    die;
